//
// Copyright 2025 Pixar
//
// Licensed under the terms set forth in the LICENSE.txt file available at
// https://openusd.org/license.
//
#include "pxr/usdImaging/usdSkelImaging/tokens.h"

PXR_NAMESPACE_OPEN_SCOPE

TF_DEFINE_PUBLIC_TOKENS(
    UsdSkelImagingPrimTypeTokens,
    USD_SKEL_IMAGING_PRIM_TYPE_TOKENS);

TF_DEFINE_PUBLIC_TOKENS(
    UsdSkelImagingExtComputationNameTokens,
    USD_SKEL_IMAGING_EXT_COMPUTATION_NAME_TOKENS);

TF_DEFINE_PUBLIC_TOKENS(
    UsdSkelImagingExtAggregatorComputationInputNameTokens,
    USD_SKEL_IMAGING_EXT_AGGREGATOR_COMPUTATION_INPUT_NAME_TOKENS);

TF_DEFINE_PUBLIC_TOKENS(
    UsdSkelImagingExtComputationInputNameTokens,
    USD_SKEL_IMAGING_EXT_COMPUTATION_INPUT_NAME_TOKENS);

TF_DEFINE_PUBLIC_TOKENS(
    UsdSkelImagingExtComputationLegacyInputNameTokens,
    USD_SKEL_IMAGING_EXT_COMPUTATION_LEGACY_INPUT_NAME_TOKENS);

TF_DEFINE_PUBLIC_TOKENS(
    UsdSkelImagingExtComputationOutputNameTokens,
    USD_SKEL_IMAGING_EXT_COMPUTATION_OUTPUT_NAME_TOKENS);

PXR_NAMESPACE_CLOSE_SCOPE
